From b50177e00f35929f0ccce544aa78b49b3f168da2 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Juho=20V=C3=A4h=C3=A4-Herttua?= <juhovh@iki.fi>
Date: Mon, 2 Aug 2010 12:51:18 +0300
Subject: [PATCH] Qt: Handle signals correctly on Mac OS X, including Force Quit.

Also fixes an issue caused by commit 4d636fa3a74924691b0b earlier.
---
 modules/gui/qt4/qt4.cpp |   15 +++++++++++++++
 1 files changed, 15 insertions(+), 0 deletions(-)

diff --git a/modules/gui/qt4/qt4.cpp b/modules/gui/qt4/qt4.cpp
index cbd622c..28b88ad 100644
--- a/modules/gui/qt4/qt4.cpp
+++ b/modules/gui/qt4/qt4.cpp
@@ -284,10 +284,15 @@ static struct
 
 #ifdef Q_WS_MAC
 /* Used to abort the app.exec() on OSX after libvlc_Quit is called */
+#include <signal.h> /* sigemptyset and sigaddset */
 #include "../../../src/control/libvlc_internal.h" /* libvlc_SetExitHandler */
 static void Abort( void *obj )
 {
     QVLCApp::triggerQuit();
+
+    /* Make sure that we quit in the sigwait */
+    pthread_t self = pthread_self();
+    pthread_kill( self, SIGINT );
 }
 #endif
 
@@ -501,6 +506,16 @@ static void *Thread( void *obj )
     /* We took over main thread, register and start here */
     if( !p_intf->p_sys->b_isDialogProvider )
     {
+        sigset_t set;
+
+        /* Make sure the "force quit" menu item does quit instantly.
+         * VLC overrides SIGTERM which is sent by the "force quit"
+         * menu item to make sure deamon mode quits gracefully, so
+         * we un-override SIGTERM here. */
+        sigemptyset( &set );
+        sigaddset( &set, SIGTERM );
+        pthread_sigmask( SIG_UNBLOCK, &set, NULL );
+
         RegisterIntf( (vlc_object_t *)p_intf );
         playlist_Play( p_intf->p_sys->p_playlist );
     }
-- 
1.6.5.7

